@@ -7,7 +7,7 @@ function HGEditor(container, language){
 /**
 * Creates an editor inside the given container (replaces inner HTML) with highlighting in the given language.
 */
-  container.innerHTML = "<div id=HGInnerEditor" + HGEditorNum + "></div>"; // container used as a handle
+  container.innerHTML = "<div id=HGInnerEditor" + HGEditorNum + " style='height:500px;width:800px'></div>"; // container used as a handle
   var editor = ace.edit("HGInnerEditor" + HGEditorNum);
   editor.setTheme("ace/theme/monokai");
   editor.session.setMode("ace/mode/" + language);
