@@ -50,12 +50,6 @@ def readID(found, counter, tagType, pos = 0):
 def hg_js_tag_processor(task):
     """Replaces tags for different inputs with replacable HTML-Elements and creates code for conversion."""
     converters = ""
-    converters += """
-    if(typeof HGFeedbackMap == 'undefined'){
-      HGFeedbackMap = {};
-      HGFeedbackOnlyList = [];
-    }
-    """
     IDCount = {} # we count the HGIDs to warn the user of duplicates
 # feedback-only content
     reg = re.compile('\[feedbackOnly(\([^)]+?\))\]([\w\W\s]*?)(\[\/feedbackOnly\])', re.MULTILINE) 
@@ -104,9 +98,6 @@ def hg_js_tag_processor(task):
             feedback = feedback.replace('"', '\\"') # auto-escape double-quotes
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempEditor.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + escapeLineBreaks(feedback) + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGEDITORINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGEDITORINPUTPLACE")    
@@ -138,9 +129,6 @@ def hg_js_tag_processor(task):
             feedback = feedback.replace('"', '\\"') # auto-escape double-quotes
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempField.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + feedback + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGTEXTFIELDINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGTEXTFIELDINPUTPLACE") 
@@ -172,9 +160,6 @@ def hg_js_tag_processor(task):
             feedback = feedback.replace('"', '\\"') # auto-escape double-quotes
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempField.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + feedback + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGINLINETEXTFIELDINPUTPLACE", task)
     task = InterleaveWithTags(task, "span", IDs, "HGINLINETEXTFIELDINPUTPLACE") 
@@ -204,9 +189,6 @@ def hg_js_tag_processor(task):
             feedback = feedback.replace('"', '\\"') # auto-escape double-quotes
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempArea.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + escapeLineBreaks(feedback) + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGTEXTAREAINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGTEXTAREAINPUTPLACE") 
@@ -280,9 +262,6 @@ def hg_js_tag_processor(task):
             feedback = feedback[1:-1] # remove enclosing brackets
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempCheckBoxes.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + feedback.replace(",", CHECK_BOX_SEPARATOR) + "\"").replace("{HGID}", "\"" + ID + "\"") # also replace the commata inside the feedback with the separator
     task = re.sub(reg, "HGCHECKBOXINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGCHECKBOXINPUTPLACE") 
@@ -291,18 +270,19 @@ def hg_js_tag_processor(task):
     #\[(\\*?)radioButtons(\([^)]+?\))\] - finds the initial tag with HGID, for example [radioButtons(myRadioButtons)] including the possible alias-star
     #([\w\W]*?) - takes everything the middle of the tags, supposed to be the comma-separated selectable values
     #(\[\/radioButtons(\([^\)]*?\))?\]) - finds closing [/radioButtons(feedback)] or [/radioButtons] with feedback being the correct answer (written the same as between the tags)
-    extraReg = re.compile('([^,]*)([\W]*)', re.MULTILINE) # for the contained comma-separated values
+    extraReg = re.compile('([^,\[]*)([^,]*)', re.MULTILINE) # for the contained comma-separated values
     #([^,]*) - everything up to a comma (should be the checkable options) 
     #([\W]*) - any non-alphanumeric characters afterwards (filters out the commata and spaces etc.)
     IDs = [];
     for point in re.finditer(reg, task):
         options = []
         values = []
+        odd = True # every second regex output is not relevant
         for option in re.finditer(extraReg, point.groups()[2]): # read the comma-separated options and put them in a list
-            options.append(option.groups()[0].replace("\\","\\\\"))
-            values.append(option.groups()[0].replace("\\","\\\\"))
-        options = options[0:-1] # the loop before adds an empty option in the end
-        values = values[0:-1]
+            if(odd):
+                options.append(option.groups()[0].replace("\\","\\\\"))
+                values.append(option.groups()[0].replace("\\","\\\\"))
+            odd = not odd
         if(point.groups()[0] != None): # alias star contained: change options and values
             aliasReg = re.compile("([\w\W]*):([\w\W]*)", re.MULTILINE)
             for optionNum in range(len(options)):
@@ -347,9 +327,6 @@ def hg_js_tag_processor(task):
             feedback = feedback[1:-1] # remove enclosing brackets
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempRadios.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + feedback + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGRADIOSINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGRADIOSINPUTPLACE") 
@@ -358,18 +335,19 @@ def hg_js_tag_processor(task):
     #\[(\\*?)selection(\([^)]+?\))\] - finds the initial tag with HGID, for example [selection(mySelection)] including the possible alias-star
     #([\w\W]*?) - takes everything the middle of the tags, supposed to be the comma-separated selectable values
     #(\[\/selection(\([^\)]*?\))?\]) - finds closing [/selection(feedback)] or [/selection] with feedback being the correct answer (written the same as between the tags)
-    extraReg = re.compile('([^,]*)([\W]*)', re.MULTILINE) # for the contained comma-separated values
+    extraReg = re.compile('([^,\[]*)([^,]*)', re.MULTILINE) # for the contained comma-separated values
     #([^,]*) - everything up to a comma (should be the checkable options) 
     #([\W]*) - any non-alphanumeric characters afterwards (filters out the commata and spaces etc.)
     IDs = [];
     for point in re.finditer(reg, task):
         options = []
         values = []
+        odd = True # every second regex output is not relevant
         for option in re.finditer(extraReg, point.groups()[2]): # read the comma-separated options and put them in a list
-            options.append(option.groups()[0].replace("\\","\\\\"))
-            values.append(option.groups()[0].replace("\\","\\\\"))
-        options = options[0:-1] # the loop before adds an empty option in the end
-        values = values[0:-1]
+            if(odd):
+                options.append(option.groups()[0].replace("\\","\\\\"))
+                values.append(option.groups()[0].replace("\\","\\\\"))
+            odd = not odd
         if(point.groups()[0] != None): # alias star contained: change options and values
             aliasReg = re.compile("([\w\W]*):([\w\W]*)", re.MULTILINE)
             for optionNum in range(len(options)):
@@ -404,9 +382,6 @@ def hg_js_tag_processor(task):
             feedback = feedback[1:-1] # remove enclosing brackets
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempSelection.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + feedback + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGSELECTIONINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGSELECTIONINPUTPLACE") 
@@ -442,9 +417,6 @@ def hg_js_tag_processor(task):
             imageType = os.path.splitext(feedbackPath)[1][1:]
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempCanvas.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{feedback}", "\"" + picPathToDataURL(feedbackPath) + "\"").replace("{HGID}", "\"" + ID + "\"")
     task = re.sub(reg, "HGDRAWINGCANVASINPUTPLACE", task)
     task = InterleaveWithTags(task, "div", IDs, "HGDRAWINGCANVASINPUTPLACE") 
@@ -485,7 +457,7 @@ def hg_js_tag_processor(task):
     IDs = [];
     once = True # if true, first checkBox (in this part of the task, copy when reviewing answers will have a new first checkBox)
     for point in re.finditer(reg, task):
-        if(once): # if first checkbox add HGCheckBoxSeparator as a global var (could be done multiple times too)
+        if(once): # if first variable table add separators as global vars (could be done multiple times too)
             once = False
             converters += "HGVTableRowSeparator = '" + VARIABLE_TABLE_ROW_SEPARATOR + "';"
             converters += "HGVTableColumnSeparator = '" + VARIABLE_TABLE_COLUMN_SEPARATOR + "';"
@@ -508,9 +480,6 @@ def hg_js_tag_processor(task):
             feedback = feedback.replace(";", VARIABLE_TABLE_COLUMN_SEPARATOR).replace(",", VARIABLE_TABLE_ROW_SEPARATOR).replace('"', "&#34").replace("'", "&#39")
             converters += """
             HGFeedbackMap[{HGID} + "num" + HGInstance] = {feedback};
-            if(HGInstance == HGFeedbackInstance && !HGIsExamReviewGlobal){
-              HGTempVariableTable.HGSetter(HGFeedbackMap[{HGID} + "num" + HGInstance]);
-            }
             """.replace("{HGID}", "\"" + ID + "\"").replace("{feedback}", "\"" + feedback + "\"") # also replace the commata inside the feedback with the separator
     task = re.sub(reg, "HGVARIABLETABLEINPUTPLACE", task)
     task = InterleaveWithTags(task, "p", IDs, "HGVARIABLETABLEINPUTPLACE")   
@@ -566,15 +535,7 @@ def hg_js_tag_processor(task):
                 HGSaveAll(); // immediately save the changed metadata and send it to the server to minimize abusability
                 if(HGSaveToServer()){ 
                   HGRegisterEvaluator(blockEval); // block further input
-                  var inputs = document.querySelectorAll("[HGInput]") // get all inputs
-                  for (var InpNum = 0; InpNum < inputs.length; InpNum++){
-                    if(typeof HGFeedbackMap[inputs[InpNum].getAttribute("HGInput")] != "undefined"){ // if feedback exists, set content to feedback
-                      inputs[InpNum].HGSetter(HGFeedbackMap[inputs[InpNum].getAttribute("HGInput")] );
-                    }
-                  }
-                  for (var FBONum = 0; FBONum < HGFeedbackOnlyList.length; FBONum++){ // go through feedback-only-parts and display them
-                    HGFeedbackOnlyList[FBONum].removeAttribute("hidden");
-                  }
+                  HGShowFeedback();
                 }
                 else{
                   HGMetaData["viewedSolution"]="no";
